@@ -8,6 +8,10 @@ module Specinfra
         @instance ||= self.new
       end
 
+      def self.clear
+        @instance = nil
+      end
+
       def initialize(config = {})
         @config = config
       end
@@ -29,6 +33,8 @@ module Specinfra
             return @os_info
           end
         end
+
+        raise NotImplementedError, 'OS detection failed.'
       end
 
       def command
@@ -42,6 +48,14 @@ module Specinfra
       def set_example(e)
         @example = e
       end
+
+      def stdout_handler=(block)
+        @stdout_handler = block
+      end
+
+      def stderr_handler=(block)
+        @stderr_handler = block
+      end
     end
   end
 end
